pecos.tools.fault\_tolerance\_checks
====================================

.. automodule:: pecos.tools.fault_tolerance_checks

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      dist_mode_powerset
      dist_mode_smallest
      dist_mode_x
      dist_mode_z
      distance_check
      fault_check
      powerset
      t_errors_check
   
   

   
   
   

   
   
   



